NAME
PerlBean::Method::Constructor - contains bean constructor method information
SYNOPSIS
TODO
ABSTRACT
Abstract PerlBean method information
DESCRIPTION
PerlBean::Method class for bean constructor method information. This is a subclass from PerlBean::Method with the purpose to diferenciate beteen plain methods and constructors.
CONSTRUCTOR
- new(OPT_HASH_REF)
-
Creates a new
PerlBean::Method::Constructorobject.OPT_HASH_REFis a hash reference used to pass initialization options.OPT_HASH_REFis mandatory. On error an exceptionError::Simpleis thrown.Options for
OPT_HASH_REFinherited through packagePerlBean::Methodmay include:body-
Passed to set_body().
description-
Passed to set_description().
exception_class-
Passed to set_exception_class(). Defaults to 'Error::Simple'.
interface-
Passed to set_interface().
method_name-
Passed to set_method_name(). Mandatory option.
parameter_description-
Passed to set_parameter_description().
perl_bean-
Passed to set_perl_bean().
METHODS
- get_package()
-
This method is inherited from package
'PerlBean::Method'. Returns the package name. The package name is obtained from thePerlBeanto which thePerlBean::Attributebelongs. Or, if thePerlBean::Attributedoes not belong to aPerlBean,mainis returned. - get_super_method()
-
This method is inherited from package
'PerlBean::Method'. Search the superclasses hierarchy for an identically namedPerlBean::Methodand return it. If no method is foundundefis returned. - write_code(FILEHANDLE)
-
This method is inherited from package
'PerlBean::Method'. Write the code for the method toFILEHANDLE.FILEHANDLEis anIO::Handleobject. On error an exceptionError::Simpleis thrown. - write_pod(FILEHANDLE)
-
This method is inherited from package
'PerlBean::Method'. Write the documentation for the method toFILEHANDLE.FILEHANDLEis anIO::Handleobject. On error an exceptionError::Simpleis thrown.
INHERITED METHODS FROM PerlBean::Method
- To access attribute named
body: -
set_body(), get_body()
- To access attribute named
description: -
set_description(), get_description()
- To access attribute named
exception_class: -
set_exception_class(), get_exception_class()
- To access attribute named
interface: -
set_interface(), is_interface()
- To access attribute named
method_name: -
set_method_name(), get_method_name()
- To access attribute named
parameter_description: -
set_parameter_description(), get_parameter_description()
- To access attribute named
perl_bean: -
set_perl_bean(), get_perl_bean()
SEE ALSO
PerlBean, PerlBean::Attribute, PerlBean::Attribute::Boolean, PerlBean::Attribute::Factory, PerlBean::Attribute::Multi, PerlBean::Attribute::Multi::Ordered, PerlBean::Attribute::Multi::Unique, PerlBean::Attribute::Multi::Unique::Associative, PerlBean::Attribute::Multi::Unique::Associative::MethodKey, PerlBean::Attribute::Multi::Unique::Ordered, PerlBean::Attribute::Single, PerlBean::Collection, PerlBean::Method, PerlBean::Style
BUGS
None known (yet.)
HISTORY
First development: February 2003
AUTHOR
Vincenzo Zocca
COPYRIGHT
Copyright 2003 by Vincenzo Zocca
LICENSE
This file is part of the PerlBean module hierarchy for Perl by Vincenzo Zocca.
The PerlBean module hierarchy is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.
The PerlBean module hierarchy is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
You should have received a copy of the GNU General Public License along with the PerlBean module hierarchy; if not, write to the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA